@@ -1,6 +1,6 @@
 import pandas as pd
 import os
-from configparser import ConfigParser
+from configparser import ConfigParser, MissingSectionHeaderError, NoSectionError, NoOptionError
 import glob
 import re
 import sys
@@ -27,6 +27,10 @@ def define_bp_drop_down(configini):
     configFile = str(configini)
     config.read(configFile)
     animalno = config.getint('General settings', 'animal_no')
+    try:
+        IDList = config.get('Multi animal IDs', 'id_list')
+    except NoSectionError:
+        IDList = []
     # get list
     bpcsv = (os.path.join(os.path.dirname(configini), 'logs', 'measures', 'pose_configs', 'bp_names', 'project_bp_names.csv'))
     bplist = []
@@ -35,20 +39,36 @@ def define_bp_drop_down(configini):
             bplist.append(row)
     bplist = list(map(lambda x: x.replace('\n', ''), bplist))
 
-    if animalno != 1:
-        animal1bp = [f for f in bplist if '_1' in f]
-        animal2bp = [f for f in bplist if '_2' in f]
-        return animal1bp,animal2bp
-    else:
-        animal1bp = bplist
-        return animal1bp,['No body parts']
+    if not IDList:
+        if animalno != 1:
+            animal1bp = [f for f in bplist if '_1' in f]
+            animal2bp = [f for f in bplist if '_2' in f]
+            return animal1bp,animal2bp
+        else:
+            animal1bp = bplist
+            return animal1bp,['No body parts']
+    if IDList:
+        if animalno != 1:
+            IDList = IDList.split(",")
+            animal1bp = [f for f in bplist if IDList[0] in f]
+            animal2bp = [f for f in bplist if IDList[1] in f]
+            return animal1bp, animal2bp
+        else:
+            animal1bp = bplist
+            return animal1bp,['No body parts']
+
 
 def define_movement_cols(noAnimals):
     if noAnimals == 1:
         columnNames = ['Video', 'Frames processed', 'Total movement', 'Mean velocity', 'Median velocity']
-    if noAnimals == 2:
+    elif noAnimals == 2:
         columnNames = ['Video', 'Frames processed', 'Total movement animal 1', 'Mean velocity animal 1', 'Median velocity animal 1', 'Total movement animal 2', 'Mean velocity animal 2', 'Median velocity animal 2', 'Mean animal distance', 'Median animal distance']
-    print(columnNames)
+    else:
+        columnNames = ['Video', 'Frames processed']
+        for animal in range(noAnimals):
+            column2add = ['Total movement animal ' + str(animal+1), 'Mean velocity animal ' + str(animal+1), 'Median velocity animal ' + str(animal+1)]
+            columnNames.extend(column2add)
+
     return columnNames
 
 def bodypartConfSchematic():
@@ -105,4 +125,37 @@ def getBpHeaders(inifile):
         colHeads.append(colHead1)
         colHeads.append(colHead2)
         colHeads.append(colHead3)
-    return colHeads
\ No newline at end of file
+    return colHeads
+
+
+def create_body_part_dictionary(multiAnimalStatus, multiAnimalIDList, animalsNo, Xcols, Ycols, Pcols, colorListofList):
+    animalBpDict = {}
+    if multiAnimalStatus == True:
+        for animal in range(animalsNo):
+            animalBpDict[multiAnimalIDList[animal]] = {}
+            animalBpDict[multiAnimalIDList[animal]]['X_bps'] = [i for i in Xcols if multiAnimalIDList[animal] in i]
+            animalBpDict[multiAnimalIDList[animal]]['Y_bps'] = [i for i in Ycols if multiAnimalIDList[animal] in i]
+            if colorListofList:
+                animalBpDict[multiAnimalIDList[animal]]['colors'] = colorListofList[animal]
+            if Pcols:
+                animalBpDict[multiAnimalIDList[animal]]['P_bps'] = [i for i in Pcols if multiAnimalIDList[animal] in i]
+    else:
+        if animalsNo > 1:
+            for animal in range(animalsNo):
+                currAnimalName = 'Animal_' + str(animal + 1)
+                animalBpDict[currAnimalName] = {}
+                animalBpDict[currAnimalName]['X_bps'] = [i for i in Xcols if currAnimalName in i]
+                animalBpDict[currAnimalName]['Y_bps'] = [i for i in Ycols if currAnimalName in i]
+                if colorListofList:
+                    animalBpDict[currAnimalName]['colors'] = colorListofList[animal]
+                if Pcols:
+                    animalBpDict[currAnimalName]['P_bps'] = [i for i in Pcols if currAnimalName in i]
+        else:
+            animalBpDict['Animal_1'] = {}
+            animalBpDict['Animal_1']['X_bps'] = [i for i in Xcols]
+            animalBpDict['Animal_1']['Y_bps'] = [i for i in Ycols]
+            if colorListofList:
+                animalBpDict['Animal_1']['colors'] = colorListofList[0]
+            if Pcols:
+                animalBpDict['Animal_1']['P_bps'] = [i for i in Pcols]
+    return animalBpDict
\ No newline at end of file
